@@ -1,6 +1,6 @@
 package org.gcube.portlets.user.tdcolumnoperation.client.properties;
 
-import org.gcube.portlets.user.td.gwtservice.shared.tr.ColumnData;
+import org.gcube.portlets.user.td.widgetcommonevent.shared.tr.column.ColumnData;
 
 import com.google.gwt.editor.client.Editor.Path;
 import com.sencha.gxt.data.shared.LabelProvider;
